"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _lngFromReq = _interopRequireDefault(require("./lng-from-req"));

var _redirectWithoutCache = _interopRequireDefault(require("./redirect-without-cache"));

var _defaultConfig = require("../config/default-config");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = (req, res) => {
  if (req.i18n) {
    const language = (0, _lngFromReq.default)(req);
    const {
      allLanguages,
      defaultLanguage,
      localeSubpaths
    } = req.i18n.options;
    let languageChanged = false;
    /*
      If a user has hit a subpath which does not
      match their language, give preference to
      the path, and change user language.
    */

    allLanguages.forEach(lng => {
      if (req.url.startsWith(`/${lng}/`) && language !== lng) {
        req.i18n.changeLanguage(lng);
        languageChanged = true;
      }
    });
    /*
      If a user has hit the root path and their
      language is not set to default, give
      preference to the language and redirect
      their path.
    */

    const languageNeedsSubpath = localeSubpaths === _defaultConfig.localeSubpathOptions.FOREIGN && language !== defaultLanguage || localeSubpaths === _defaultConfig.localeSubpathOptions.ALL;

    if (!languageChanged && languageNeedsSubpath && !req.url.startsWith(`/${language}/`)) {
      allLanguages.forEach(lng => {
        if (req.url.startsWith(`/${lng}/`)) {
          req.url = req.url.replace(`/${lng}/`, '/');
        }
      });
      (0, _redirectWithoutCache.default)(res, req.url.replace('/', `/${language}/`));
    }
    /*
      If a user has a default language prefix
      in their URL, strip it.
    */


    if (language === defaultLanguage && req.url.startsWith(`/${defaultLanguage}/`) && localeSubpaths !== _defaultConfig.localeSubpathOptions.ALL) {
      (0, _redirectWithoutCache.default)(res, req.url.replace(`/${defaultLanguage}/`, '/'));
    }
  }
};

exports.default = _default;
module.exports = exports.default;
module.exports.default = exports.default;